@@ -1,7 +1,7 @@
 /*
    Kickshaw - A Menu Editor for Openbox
 
-   Copyright (c) 2010–2022        Marcus Schätzle
+   Copyright (c) 2010–2024        Marcus Schätzle
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -118,7 +118,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
         // Prevent that menus are dragged into themselves.
         if (STREQ (type_txt_loop, "menu") && dest_path_drag_motion && 
             gtk_tree_path_is_descendant (dest_path_drag_motion, source_path_loop)) {
-            statusbar_txt = "!!! Menus can't be dragged into themselves !!!";
+            statusbar_txt = _("!!! Menus can't be dragged into themselves !!!");
 
             break;
         }
@@ -143,7 +143,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
             (STREQ (type_txt_loop, "option") && 
             streq_any (menu_element_txt_loop, "enabled", "name", "wmclass", "icon", NULL) && 
             !STREQ (type_dest_parent_txt, "option block"))) {
-            statusbar_txt = "!!! Invalid new position !!!";
+            statusbar_txt = _("!!! Invalid new position !!!");
 
             break;
         }
@@ -152,7 +152,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
         if (ks.settings.autosort_options && streq_any (type_txt_loop, "option", "option block", NULL) && 
             streq_any (menu_element_dest_parent_txt, "Execute", "startupnotify", NULL) &&
             gtk_tree_path_compare (source_parent_path, dest_parent_path) == 0) {
-            statusbar_txt = "!!! Autosorting active - no movement of options inside the same action possible !!!";
+            statusbar_txt = _("!!! Autosorting active - no movement of options inside the same action possible !!!");
 
             break;
         }
@@ -168,7 +168,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
                 gtk_tree_model_iter_nth_child (ks.ts_model, &option_iter_loop, &dest_parent_iter, ch_cnt);
                 gtk_tree_model_get (ks.ts_model, &option_iter_loop, TS_MENU_ELEMENT, &menu_element_option_txt_loop, -1);
                 if (STREQ (menu_element_txt_loop, menu_element_option_txt_loop)) {
-                    statusbar_txt = "!!! Only one option of a kind allowed !!!";
+                    statusbar_txt = _("!!! Only one option of a kind allowed !!!");
 
                     break;
                 }
@@ -182,7 +182,7 @@ gboolean drag_motion_handler (G_GNUC_UNUSED GtkWidget      *widget,
         if (STREQ (type_txt_loop, "option") && STREQ (menu_element_txt_loop, "prompt") && 
             streq_any (menu_element_dest_parent_txt, "Exit", "SessionLogout", NULL) && 
             !streq_any (value_txt_loop, "yes", "no", NULL)) {
-            statusbar_txt = "!!! Prompt option must have value \"yes\" or \"no\" !!!";
+            statusbar_txt = _("!!! Prompt option must have value \"yes\" or \"no\" !!!");
         }
     }
 
@@ -215,7 +215,7 @@ void drag_leave_handler (G_GNUC_UNUSED GtkWidget      *widget,
     their new parent by two steps:
     1. Creation of arrays of the source row's subrows that include their path depth and expansion status.
     2. Adjustment of the expansion status of each subrow according to the ones of the source row.
-    The element visibility of all menus, pipe menus, items and separators
+    The element visibility of all menus, pipe menus, items, and separators
     of subrows is also adjusted to the one of the destination parent.
 
 */
@@ -270,7 +270,7 @@ static gboolean subrows_creation_auxiliary (GtkTreeModel  *filter_model,
 
         g_ptr_array_remove_index (subrows[DD_SUBROWS_EXPANSION_STATUS], 0);
 
-        // --- Step 2b: Visibilty of menus, pipe menus, items and separators ---
+        // --- Step 2b: Visibilty of menus, pipe menus, items, and separators ---
         g_autofree gchar *element_visibility_txt_filter;
 
         gtk_tree_model_get (filter_model, filter_iter, TS_ELEMENT_VISIBILITY, &element_visibility_txt_filter, -1);
@@ -493,10 +493,8 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
         // --- Add subrows, if they exist. ---
 
         if (source_row_has_child) { // Copy all children of the source row to the new row.
-            g_autofree GtkTreeIter *subrow_iters;
-
-            const guint allocated_size = sizeof (GtkTreeIter) * GPOINTER_TO_UINT (g_ptr_array_index (subrows[DD_SUBROWS_MAX_PATH_DEPTH], 0));
-            subrow_iters = g_malloc (allocated_size);
+            g_autofree GtkTreeIter *subrow_iters = 
+                g_malloc (sizeof (GtkTreeIter) * GPOINTER_TO_UINT (g_ptr_array_index (subrows[DD_SUBROWS_MAX_PATH_DEPTH], 0)));
 
             for (guint subrows_cnt = 0; subrows_cnt < subrows[0]->len; ++subrows_cnt) {
                 gint current_path_depth = GPOINTER_TO_INT (g_ptr_array_index (subrows[DD_SUBROWS_CURRENT_PATH_DEPTH], subrows_cnt));
@@ -523,7 +521,7 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
                 gtk_tree_view_expand_row (GTK_TREE_VIEW (ks.treeview), new_path, FALSE);
             }
 
-            // Set expansions status of all subrows, and also element visibility for all menus, pipe menus, items and separators.
+            // Set expansions status of all subrows, and also element visibility for all menus, pipe menus, items, and separators.
             g_ptr_array_index (subrows[DD_SUBROWS_ROOT_VISIBILITY], 0) = copied_ts_row_fields[TS_ELEMENT_VISIBILITY];
 
             g_autoptr(GtkTreeModel) filter_model = gtk_tree_model_filter_new (ks.ts_model, new_path);
@@ -591,10 +589,10 @@ void drag_drop_handler (G_GNUC_UNUSED GtkWidget      *widget,
 
     g_signal_handler_unblock (selection, ks.handler_id_row_selected);
 
-    push_new_item_on_undo_stack (FALSE); // First update undo stack so ...
+    push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
     activate_change_done ();
-    row_selected ();                     /* ... the toolbar buttons and 
-                                                application menu's undo/redo items get the correct sensitivity settings. */
+    row_selected ();                              /* ... the toolbar buttons and 
+                                                     application menu's undo/redo items get the correct sensitivity settings. */
 
 #if !(GLIB_CHECK_VERSION(2,56,0))
     // Cleanup
